@@ -158,7 +158,7 @@ ife <- function(x, a, b) {
 #'
 #' If mu is length 1 then just uses rnorm instead.
 sample_mvnorm <- function(mu, sigma) {
-    if (length(sigma) == 1 & length(mu) == 1) {
+    if (length(sigma) == 1 && length(mu) == 1) {
         return(rnorm(1, mu, sqrt(sigma)))
     }
     assert_that(
@@ -248,7 +248,7 @@ is_absent <- function(x, na = TRUE, blank = TRUE) {
         }
     }
 
-    if (blank & is.character(x)) {
+    if (blank && is.character(x)) {
         if (all(x == "")) {
             return(TRUE)
         }
@@ -294,7 +294,7 @@ extract_covariates <- function(x) {
 #' ```
 str_contains <- function(x, subs) {
     strings <- x
-    res_list <- lapply(subs, function(x) grepl(x, strings, fixed = T))
+    res_list <- lapply(subs, function(x) grepl(x, strings, fixed = TRUE))
     res_matrix <- matrix(unlist(res_list), nrow = length(res_list), byrow = TRUE)
     res <- unlist(apply(res_matrix, MARGIN = 2, any, simplify = FALSE), use.names = TRUE)
     assert_that(length(res) == length(strings))
@@ -515,18 +515,92 @@ as_dataframe <- function(x) {
 
 
 
-#' Do not run this function
-#' 
-#' This function only exists to suppress the false positive
-#' from R CMD Check about unused libraries
-#' 
-#' Both rstantools and RcppParallel are required but are only used at
-#' installation time. In the case of RcppParallel it is used in the
-#' `src/Makevars` file which is created on the fly during installation
-#' by rstantools. rstantools is used in the `configure` file.
-#' 
-do_not_run <- function() {
-    rstantools::use_rstan()
-    RcppParallel::CxxFlags()
+#' Ensure `rstan` exists
+#'
+#' Checks to see if rstan exists and if not throws a helpful error message
+#' @keywords internal
+ensure_rstan <- function() {
+    if (!requireNamespace("rstan", quietly = TRUE)) {
+        stop(
+            "In order to use `method_bayes()` the `rstan` package must be installed.",
+            " This can be installed from CRAN by running:\n\n",
+            "      install.packages('rstan')\n\n",
+            "Please note that for `rstan` to work you need to ensure you have a valid C++ toolchain;",
+            " for details please see:\n",
+            "https://github.com/stan-dev/rstan/wiki/RStan-Getting-Started#configuring-c-toolchain\n\n"
+        )
+    }
 }
 
+#' Get Compiled Stan Object
+#'
+#' Gets a compiled Stan object that can be used with `rstan::sampling()`
+#' @keywords internal
+get_stan_model <- function() {
+    ensure_rstan()
+    local_file <- file.path("inst", "stan", "MMRM.stan")
+    system_file <- system.file(file.path("stan", "MMRM.stan"), package = "rbmi")
+    file_loc <- if (file.exists(local_file)) {
+        local_file
+    } else if (file.exists(system_file)) {
+        system_file
+    } else {
+        stop("Unable to find MMRM.stan; Please report this as a bug")
+    }
+    cache_dir <- getOption("rbmi.cache_dir")
+    dir.create(cache_dir, showWarnings = FALSE, recursive = TRUE)
+    file_loc_cache <- file.path(cache_dir, "MMRM.stan")
+    if (!file.exists(file_loc_cache)) {
+        message("Compiling Stan model please wait...")
+    }
+    file.copy(file_loc, file_loc_cache, overwrite = TRUE)
+    rstan::stan_model(
+        file = file_loc_cache,
+        auto_write = TRUE,
+        model_name = "rbmi_mmrm"
+    )
+}
+
+
+
+#' rbmi settings
+#'
+#' @description
+#' Define settings that modify the behaviour of the `rbmi` package
+#'
+#' Each of the following are the name of options that can be set via:
+#' ```
+#' options(<option_name> = <value>)
+#' ```
+#'
+#' ## `rbmi.cache_dir`
+#'
+#' Default = `tools::R_user_dir("rbmi", which = "cache")`
+#'
+#' Directory to store compiled Stan model in. If not set, a temporary directory is used for
+#' the given R session. Can also be set via the environment variable `RBMI_CACHE_DIR`.
+#'
+#'
+#' @examples
+#' \dontrun{
+#' options(rbmi.cache_dir = "some/directory/path")
+#' }
+#' @name rbmi-settings
+set_options <- function() {
+
+    cache_dir <- Sys.getenv("RBMI_CACHE_DIR")
+
+    if (cache_dir == "" || is.null(cache_dir)) {
+        cache_dir <- tools::R_user_dir("rbmi", which = "cache")
+    }
+
+    current_opts <- names(options())
+    rbmi_opts <- list(
+        rbmi.cache_dir = cache_dir
+    )
+    for (opt in names(rbmi_opts)) {
+        if (!opt %in% current_opts) {
+            options(rbmi_opts[opt])
+        }
+    }
+}
